DebounceOperation class

The operation that must be performed is the callback It will be perfomed when the timer completes and only if the timer has not been cancelled before

Annotations

Constructors

DebounceOperation(VoidCallback callback, Timer timer)
The operation that must be performed is the callback It will be perfomed when the timer completes and only if the timer has not been cancelled before
const

Properties

callback → VoidCallback
The callback to be performed
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timer Timer
The timer that will trigger the callback
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited