Until<T> extension

Extension that adds the until method to SignalBase classes.

on

Methods

until(bool condition(T value), {Duration? timeout}) FutureOr<T>

Available on SignalBase<T>, provided by the Until extension

Returns the future that completes when the condition evaluates to true. If the condition is already true, it completes immediately.